const fs = require('fs')

const changelogContent = fs.readFileSync('CHANGELOG.md', 'utf-8')
const lines = changelogContent.split('\n')

const h2Regex = /^##\s+(.*)$/
const versionRegex = /^v\d+\.\d+\.\d+$/

let allH2sCompliant = true

for (let lineNumber = 0; lineNumber < lines.length; lineNumber++) {
  const line = lines[lineNumber]

  // Check for h2 headings
  const h2Match = line.match(h2Regex)
  if (h2Match) {
    const h2Heading = h2Match[1]

    // Check if h2 is in the correct format
    const isCompliant = versionRegex.test(h2Heading) || h2Heading === 'Unreleased'
    if (!isCompliant) {
      allH2sCompliant = false
      console.error(`Non-compliant h2 "${h2Heading}" found on line ${lineNumber + 1}`)
    }
  }
}

if (!allH2sCompliant) {
  console.error('Some h2 headings are not in the correct format. Failing the workflow.')
  process.exit(1)
}

console.log('All h2 headings are compliant!')
