const fs = require('fs')

const changelogContent = fs.readFileSync('CHANGELOG.md', 'utf-8')
const lines = changelogContent.split('\n')

const h3Regex = /^###\s+(.*)$/
const requiredKeywords = ['Added', 'Changed', 'Deprecated', 'Removed', 'Fixed', 'Security', 'BREAKING CHANGES']

let allH3sCompliant = true

for (let lineNumber = 0; lineNumber < lines.length; lineNumber++) {
  const line = lines[lineNumber]

  // Check for h3 heading
  const h3Match = line.match(h3Regex)
  if (h3Match) {
    const h3Heading = h3Match[1].trim()

    // Check if h3 exactly matches one of the required keywords
    const isCompliant = requiredKeywords.includes(h3Heading)
    if (!isCompliant) {
      allH3sCompliant = false
      console.error(`Non-compliant h3 "${h3Heading}" found on line ${lineNumber + 1}`)
    }
  }
}

if (!allH3sCompliant) {
  console.error('Some h3 headings are not compliant. Failing the workflow.')
  process.exit(1)
}

console.log('All h3 headings are compliant!')
