
import { faker } from '@faker-js/faker';
import { Primary } from '../Button.stories.js'
import { WithIconLeft } from '../Tag.stories.js'

/**
 * A single cell component to be used in a table body.
 * 
 * These previews are easier to see on a dark background.
 * 
 * Please ignore the last preview (BodyCellComponentTemplate) - it is only exported to be used in the row component, and cannot display properly on its own.
 * */
export default {
  title: 'Components/Table/BodyCell',
  tags: ['autodocs'],
  argTypes: {
    content: {
      control: 'text',
      description: 'Content of the cell, can be plain text or any renderable React element.',
    },
  },
  args: {
    content: 'Body cell content',
  },
}

// Standalone template for the body cell component
const BodyCellComponentTemplate = ({ content }) => {
  return `
      <td class='rpf-table-cell rpf-table-cell--body '>
        <div class='rpf-table-cell__content' >
          ${content}
        </div>
      </td>`
}

// Wrapper template for the preview with the <table> tag (won't display correctly in Storybook without this)
const PreviewTemplate = (args) => {
  return `
    <table class='rpf-table__table'>
      ${BodyCellComponentTemplate(args)}
    </table>
  `;
};

export const BodyCell = PreviewTemplate.bind({})
BodyCell.args = {
  content: 'Body cell content',
}

export const WithTagComponent = PreviewTemplate.bind({})
WithTagComponent.args = {
  content: WithIconLeft({ text: faker.person.jobTitle(),}),
}

export const WithButton = PreviewTemplate.bind({})
WithButton.args = {
  content: Primary({ text: 'Body cell content'}),
}

// Export BodyCellComponentTemplate for row component to use
export { BodyCellComponentTemplate };
