// import { TextAndIcon } from '../Button.stories.js'

/**
 * A single header cell component to be used in a table.
 * 
 * Please ignore the last preview (HeaderCellComponentTemplate) -
 * it is only exported to be used in the row component, and cannot display properly on its own.
 */
export default {
  title: 'Components/Table/HeaderCell',
  tags: ['autodocs'],
  argTypes: {
    content: {
      control: 'text',
    },
    sort: {
      control: 'boolean',
    },
    sortDirection: {
      control: 'select',
      description: 'The direction of the sort arrow. Only applicable if `sort` is true.',
      options: ['up', 'down'],
    },
    sortType: {
      control: 'select',
      description: 'This is to demonstrate different ways to wrap the header cell if sort is true. \
        It doesn\'t matter if you use a button or an anchor tag to wrap the sortable header, \
        as long as you add the correct classname and icon span.',
      options: ['button', 'link'],
    },
  },
  args: {
    content: 'Header cell',
    sort: false,
    sortDirection: 'up',
    sortType: 'button',
  },
}

// Standalone template for the header cell component
const BaseHeaderCellComponentTemplate = (args) => {
  // If there is no content, mark as a <td> tag for accessibility
  const headerTag = args.content ? 'th' : 'td';
  
  // Select the type of sort to use (button or link)
  const SortableHeaderContent = args.sortType === 'button' ? SortableHeaderUsingButtonContent(args) : SortableHeaderUsingLinkContent(args)
  return `
    <${headerTag} class='rpf-table-cell rpf-table-cell--${args.sort ? 'sortable-' : ''}header'>
      <div class='rpf-table-cell__content'>
        ${args.sort ? SortableHeaderContent : args.content}
      </div>
    </${headerTag}>
  `;
}

const SortableHeaderUsingButtonContent = (args) => {
  return `
    <button class='rpf-table-cell__sort-header'>
      ${args.content}
      <span class='material-symbols-sharp'>arrow_drop_${args.sortDirection}</span>
    </button>
  `;
}

// Should we show that it works the same with a link tag? Add a control for the sortable tag type?
const SortableHeaderUsingLinkContent = (args) => {
  return `
    <a href='#' class='rpf-table-cell__sort-header'>
      ${args.content}
      <span class='material-symbols-sharp'>arrow_drop_${args.sortDirection}</span>
    </a>
  `;
}

// Wrapper template for the preview with the <table> tag (won't display correctly in Storybook without this)
const PreviewTemplate = (args) => {
  return `
    <table>
      ${BaseHeaderCellComponentTemplate(args)}
    </table>
  `;
};

export const HeaderCell = PreviewTemplate.bind({})
HeaderCell.args = {
  content: 'Header cell',
}

// Export HeaderCellComponentTemplate for row component to use
export { BaseHeaderCellComponentTemplate };
